package App::TimeClock;

our $VERSION = "0.05";

=head1 NAME

App::TimeClock - Provides timeclock.pl, a reporting utility for timeclock, which is a time tracking package for GNU Emacs.

=head1 DESCRIPTION

Please see the documentation for L<timeclock.pl>.

=cut

1;
